@@ -25,7 +25,8 @@ def emptyEventInfo(self):
                  "number": None, #number of steps
                  "interval": None, #type of steps
                  "cron": None, #cron string
-                 "date": None} #date-syntax string
+                 "date": None, #date-syntax string
+                 "enabled": None} #1 if event is enabled, 0 if disabled
     return eventInfo
 
 def loadFieldsDict():
@@ -72,16 +73,25 @@ def loadFieldsDict():
     fields["builtins"] = builtins
     return fields
     
+def loadEventInfo(id):
+    """Load a single event from a pickled file"""
+    try:
+        file = open(JOB_DIR + id, "r")
+        eventInfo = pickle.load(file)
+        file.close()
+        return eventInfo
+    except:
+        return False
+    
 def loadEventList():
     """Load existing events by unpickling event files"""
     eventInfos = []
     if not os.path.exists(JOB_DIR):
         os.makedirs(JOB_DIR)
     for file_path in os.listdir(JOB_DIR):
-        file = open(JOB_DIR + file_path, "r")
-        eventInfo = pickle.load(file)
-        file.close()
-        eventInfos.append(eventInfo)
+        eventInfo = loadEventInfo(file_path)
+        if eventInfo:
+            eventInfos.append(eventInfo)
     return eventInfos
     
 def deleteEvent(id):
@@ -92,6 +102,17 @@ def deleteEvent(id):
         return "Event file for ID " + str(id) + " does not exist"
     return "Deleted event " + str(id)
     
+def deleteEventAlarmd(eventInfo):
+    """Deletes an event only from the alarmd queue"""
+    eventInfo["enabled"] = 0
+    deleteEvent(int(eventInfo["id"]))
+    if not os.path.exists(JOB_DIR):
+        os.makedirs(JOB_DIR)
+    job_file = open(JOB_DIR + eventInfo["id"], "w")
+    pickle.dump(eventInfo, job_file)
+    job_file.close()
+    return "Disabled event " + str(eventInfo["id"])
+    
 def savePreset(preset):
     """Saves a preset made by the user to the config dir"""
     if not os.path.exists(PRESET_DIR):
@@ -130,9 +151,11 @@ def loadPreset(preset_name):
 def getAvailableProfiles():
         """Checks if tweakr is installed and returns the profiles"""
         try:
+            print "a"
             state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
-                                 stdout=subprocess.PIPE).communicate(
+                                 stdout=subprocess.PIPE, stderr=open(os.devnull, "w")).communicate(
                                  )[0].split("\n")[5].split()[0]
+            print "b"
             if state == "ii":
                 try:
                     profiles = []
@@ -165,7 +188,7 @@ def generateEventString(eventInfo):
                                      i["daily"], i["once_a_month"], 
                                      i["end_of_month"], i["once_a_year"]]:
             eventTitle = (eventInfo["schedule"] + " " +
-                           eventInfo["type"].lower() +
+                           eventInfo["type"] +
                            " starting on " + 
                            dt.strftime("%d.%m.%Y") +
                            " at " + dt.strftime("%H:%M") + ":")
@@ -188,7 +211,7 @@ def generateEventString(eventInfo):
             for part in eventInfo["cron"]:
                 c = c + " " + part
             c = c.lstrip()
-            eventTitle = (eventInfo["type"].lower() + 
+            eventTitle = (eventInfo["type"] + 
                            " with cron mask: " + c + ":")
         elif eventInfo["schedule"] == i["date"]:
             eventTitle = (eventInfo["type"].lower() + " with date string: "
@@ -260,7 +283,7 @@ def makeEvent(eventInfo, old_id):
     """Makes a new alarmd event"""
     #make new event with timestamp and title
     event = alarm.Event()
-    event.message = eventInfo["title"]
+    eventInfo["enabled"] = 1
     try:
         event.alarm_time = eventInfo["ttime"]
         dt = datetime.datetime.fromtimestamp(eventInfo["ttime"])
@@ -273,10 +296,11 @@ def makeEvent(eventInfo, old_id):
         action_snooze, action_stop = event.add_actions(2)
         action_stop.flags |= (alarm.ACTION_WHEN_RESPONDED |
                               alarm.ACTION_TYPE_NOP)
-        action_stop.label = 'Stop'
+        action_stop.label = 'cloc_bd_stop' #'Stop'
         action_snooze.flags |= (alarm.ACTION_WHEN_RESPONDED |
                                 alarm.ACTION_TYPE_SNOOZE)
-        action_snooze.label = 'Snooze'
+        action_snooze.label = 'cloc bd alarm notification snooze' #'Snooze'
+        event.message = eventInfo["title"]
     elif eventInfo["type"] == t["exec_type"]:
         action = event.add_actions(1)[0]
         action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
@@ -314,7 +338,7 @@ def makeEvent(eventInfo, old_id):
         else:
             try:
                 state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
-                               stdout=subprocess.PIPE).communicate(
+                               stdout=subprocess.PIPE, stderr=open(os.devnull, "w")).communicate(
                                )[0].split("\n")[5].split()[0]
                 if state == "ii":
                     action.command = str(
