@@ -92,12 +92,11 @@ class AlarmedGUI(QtGui.QWidget):
             checkSum = checkSum + int(self.eventList.item(i).checkState())
         return checkSum
 
-    def toggleEvent(self):
+    def toggleEvent(self, item):
         """Enable or disable an existing event"""
         tempCheckSum = self.checkSumEventList()
         if self.checkSum != tempCheckSum:
             self.checkSum = tempCheckSum
-            item = self.eventList.currentItem()
             state = item.checkState()
             id = int(item.eventInfo["id"])
             if state == 0:
